@@ -1,8 +1,28 @@
+###############################################################################
+# copyright 2010 Edwin Marshall (aspidites) <aspidties@inbox.com>             #
+#                                                                             #
+# This file is part of MaeGym                                                 #
+#                                                                             #
+# MaeGym is free software: you can redistribute it and/or                     #
+# modify it under the terms of the GNU General Public License as published by #
+# the Free Software Foundation, either version 3 of the License, or           #
+# (at your option) any later version.                                         #
+#                                                                             #
+# MaeGym is distributed in the hope that it will be useful,                   #
+# but WITHOUT ANY WARRANTY; without even the implied warranty of              #
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
+# GNU General Public License for more details.                                #
+#                                                                             #
+# You should have received a copy of the GNU General Public License           #
+# along with MaeGym.                                                          # 
+# If not, see <http://www.gnu.org/licenses/>.                                 #
+###############################################################################
+
 # pyqt modules
 from PyQt4.QtGui import (QApplication, QLabel, QListView, QMenu, 
                          QProgressDialog, QPushButton, QMainWindow, QVBoxLayout, 
                          QWidget)
-from PyQt4.QtCore import (pyqtSignature, Qt, SIGNAL)
+from PyQt4.QtCore import (pyqtSignature, pyqtSignal, Qt)
 
 # third-party modules
 import config as c
@@ -15,33 +35,33 @@ import target_areas_window as taw
 
 from delegates import ExercisesDelegate
 
+from PyQt4.QtCore import QModelIndex
 class ExercisesWindow(QMainWindow, Ui_ExercisesWindow):
 
-    def __init__(self, parent=None, database=None, target_area=None):
+    def __init__(self, parent=None, database=None, t_name=None):
         super(ExercisesWindow, self).__init__(parent)
         self.setAttribute(Qt.WA_Maemo5StackedWindow)
 
         self.setupUi(self)
         self.config = c.Config()
         self.db = database
-        self.target_area = target_area
-        self.setupTableView()
+        self.setupListView(t_name)
 
         self.customContextMenuRequested.connect(self.openMenu)
 
-    def setupTableView(self):
-        if self.target_area:
-            filtered_exercises_model = self.db.exercises_model
-            filtered_exercises_model.setFilter("t_name='%s'" % self.target_area)
-            filtered_exercises_model.select()
+    def refreshModel(self):
+        self.model.select()
 
-            self.exercises_list_view.setModel(filtered_exercises_model)
+    def setupListView(self, t_name):
+        self.model = self.db.exercises_model(t_name)
+
+        if t_name:    
             self.target_areas_action.setEnabled(False)
+            self.routines_action.setEnabled(False)
             self.new_exercise_button.hide()
-            self.setWindowTitle(self.target_area)
-        else:
-            self.exercises_list_view.setModel(self.db.exercises_model)
+            self.setWindowTitle(t_name)
 
+        self.exercises_list_view.setModel(self.model)
         self.exercises_list_view.setModelColumn(1)
         self.exercises_list_view.setItemDelegate(ExercisesDelegate())
 
@@ -63,6 +83,7 @@ class ExercisesWindow(QMainWindow, Ui_ExercisesWindow):
 
     def on_new_exercise_button_pressed(self):
         exercise_wizard = ew.ExerciseWizard(self, self.db)
+        exercise_wizard.exercisesUpdated.connect(self.refreshModel)
         exercise_wizard.show()
 
     @pyqtSignature('QModelIndex')
@@ -78,54 +99,40 @@ class ExercisesWindow(QMainWindow, Ui_ExercisesWindow):
 
         if action == edit_action:
             index = self.exercises_list_view.currentIndex()
-            name = self.db.exercises_model.record(
-                                       index.row()).value('ex_name')
+            name = self.model.record(index.row()).value('ex_name')
 
             exercise_wizard = ew.ExerciseWizard(self, self.db, name)
+            exercise_wizard.exercisesUpdated.connect(self.refreshModel)
             exercise_wizard.setStartId(1)
             exercise_wizard.setWindowTitle('Edit Exercise')
 
-            description = self.db.exercises_model.record(
-                                index.row()).value('ex_description')
+            description = self.model.record(index.row()).value('ex_description')
 
-            t_name = self.db.exercises_model.record(
-                                          index.row()).value('t_name')
+            t_name = self.model.record(index.row()).value('t_name')
             t_id = self.db.getRow('t_name', t_name)
 
-            f_name = self.db.exercises_model.record(
-                                          index.row()).value('f_name')
+            f_name = self.model.record(index.row()).value('f_name')
             f_id = self.db.getRow('f_name', f_name)
 
-            d_name = self.db.exercises_model.record(
-                                          index.row()).value('d_name')
+            d_name = self.model.record(index.row()).value('d_name')
             d_id = self.db.getRow('d_name', d_name)
 
-            i_name = self.db.exercises_model.record(
-                                          index.row()).value('i_name')
+            i_name = self.model.record(index.row()).value('i_name')
             i_id = self.db.getRow('i_name', i_name)
 
-            e_name = self.db.exercises_model.record(
-                                          index.row()).value('e_name')
+            e_name = self.model.record(index.row()).value('e_name')
             e_id = self.db.getRow('e_name', e_name)
             
 
             """ REFERNCE
-            target_area = self.db.exercises_model.index(index.row(),
-                                                        3).data()
-            frequency = self.db.exercises_model.index(index.row(),
-                                                      4).data()
-            duration = self.db.exercises_model.index(index.row(),
-                                                    5).data()
-            intensity = self.db.exercises_model.index(index.row(),
-                                                      6).data()
-            equipment = self.db.exercises_model.index(index.row(),
-                                                      7).data()
+            target_area = self.model.index(index.row(), 3).data()
+            frequency = self.model.index(index.row(), 4).data()
+            duration = self.model.index(index.row(), 5).data()
+            intensity = self.model.index(index.row(), 6).data()
+            equipment = self.model.index(index.row(), 7).data()
             """
 
-            media = self.db.exercises_model.index(index.row(),
-                                                  8).data()
-
-
+            media = self.model.index(index.row(),8).data()
             exercise_wizard.name_line_edit.setText(name.toString())
             exercise_wizard.description_text_edit.setHtml(description.toString())
             exercise_wizard.target_area_selector.setCurrentIndex(t_id)
@@ -136,6 +143,7 @@ class ExercisesWindow(QMainWindow, Ui_ExercisesWindow):
             exercise_wizard.media_line_edit.setText(media.toString())
 
             exercise_wizard.show()
+
+
         elif action == delete_action:
-            self.db.exercises_model.removeRow(
-                                 self.exercises_list_view.currentIndex().row())
+            self.model.removeRow(self.exercises_list_view.currentIndex().row())
