@@ -4,7 +4,7 @@ import sys
 # pyqt modules
 from PyQt4.QtGui import (QApplication, QLabel, QPushButton, 
                           QMainWindow, QVBoxLayout, QWidget)
-from PyQt4.QtCore import (Qt, SIGNAL)
+from PyQt4.QtCore import (Qt)
 
 # third-party modules
 import config as c
@@ -19,5 +19,4 @@ class MealsWindow(QMainWindow, Ui_MealsWindow):
         self.setAttribute(Qt.WA_Maemo5StackedWindow)
 
         self.setupUi(self)
-
         self.config = c.Config()
