@@ -1,10 +1,30 @@
+###############################################################################
+# copyright 2010 Edwin Marshall (aspidites) <aspidties@inbox.com>             #
+#                                                                             #
+# This file is part of MaeGym                                                 #
+#                                                                             #
+# MaeGym is free software: you can redistribute it and/or                     #
+# modify it under the terms of the GNU General Public License as published by #
+# the Free Software Foundation, either version 3 of the License, or           #
+# (at your option) any later version.                                         #
+#                                                                             #
+# MaeGym is distributed in the hope that it will be useful,                   #
+# but WITHOUT ANY WARRANTY; without even the implied warranty of              #
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
+# GNU General Public License for more details.                                #
+#                                                                             #
+# You should have received a copy of the GNU General Public License           #
+# along with MaeGym.                                                          # 
+# If not, see <http://www.gnu.org/licenses/>.                                 #
+###############################################################################
+
 # builtin modules
 import sys
 
 # pyqt modules
 from PyQt4.QtGui import (QApplication, QHBoxLayout, QLabel, QPushButton, 
                          QMainWindow, QVBoxLayout, QWidget) 
-from PyQt4.QtCore import (pyqtSignature, Qt, SIGNAL)
+from PyQt4.QtCore import (pyqtSignature, Qt)
 import sip
 
 # third-party modules
@@ -30,8 +50,7 @@ class WelcomeWindow(QMainWindow, Ui_WelcomeWindow):
         self.loadConfigOptions()
         self.reflowWidgets()
 
-        self.connect(QApplication.desktop(), SIGNAL("resized(int)"), 
-                     self.reflowWidgets)
+        QApplication.desktop().resized.connect(self.reflowWidgets)
 
     def loadConfigOptions(self):
         self.config = c.Config()
@@ -76,7 +95,7 @@ class WelcomeWindow(QMainWindow, Ui_WelcomeWindow):
         self.central_widget.layout().addWidget(self.fitness_button)
         self.central_widget.layout().addWidget(self.nutrition_button)
         self.central_widget.layout().addWidget(self.progress_button)
-        self.central_widget.layout().addWidget(self.calendar_button)
+        self.central_widget.layout().addWidget(self.agenda_button)
 
     def on_fitness_button_clicked(self):
         self.fitness_window.show()
